#############

=pod

There's no real example.

With command line script, you can force the use of Pastebin.ca
by providing:
    -s PastebinCa
as the commandline argument.

See docs for App::Nopaste

=cut